@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Base;
 
-our $DATE = '2015-11-27'; # DATE
-our $VERSION = '1.40'; # VERSION
+our $DATE = '2015-11-29'; # DATE
+our $VERSION = '1.41'; # VERSION
 
 use 5.010001;
 use strict;
@@ -1244,6 +1244,18 @@ sub run {
     $r->{naked_res} = $co->{naked_res}{default} if $co->{naked_res};
     $r->{format}    = $co->{format}{default} if $co->{format};
 
+    # EXPERIMENTAL, set default format to json if we are running in a pipeline
+    # and the right side of the pipe is the 'td' program
+    {
+        last if (-t STDOUT) || $r->{format};
+        last unless eval { require Pipe::Find; 1 };
+        my $pipeinfo = Pipe::Find::get_stdout_pipe_process();
+        last unless $pipeinfo;
+        last unless $pipeinfo->{exe} =~ m![/\\]td\z! ||
+            $pipeinfo->{cmdline} =~ m!\A([^\0]*[/\\])?perl\0([^\0]*[/\\])?td\0!;
+        $r->{format} = 'json';
+    }
+
     if ($self->read_config) {
         # note that we will be reading config file
         $r->{read_config} = 1;
@@ -1392,7 +1404,7 @@ Perinci::CmdLine::Base - Base class for Perinci::CmdLine{::Classic,::Lite}
 
 =head1 VERSION
 
-This document describes version 1.40 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-11-27.
+This document describes version 1.41 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-11-29.
 
 =head1 DESCRIPTION
 
